//--------------------------------------------------------------------------------
// This file is part of the Windows Workflow Foundation Sample Code
//
// Copyright (c) Microsoft Corporation. All rights reserved.
//
// This source code is intended only as a supplement to Microsoft
// Development Tools and/or on-line documentation.  See these other
// materials for detailed information regarding Microsoft code samples.
// 
// THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//--------------------------------------------------------------------------------

using System;
using System.Configuration;
using System.Collections.Specialized;
using Microsoft.Samples.Workflow.UI;

namespace Microsoft.Samples.Workflow.UI.Asp
{
    public class PageMappingElementCollection : ConfigurationElementCollection
    {
        protected override ConfigurationElement CreateNewElement()
        {
            return new PageMappingElement();
        }

        protected override object GetElementKey(ConfigurationElement settings)
        {
            if (settings == null)
            {
                throw new ArgumentNullException("settings");
            }

            return ((PageMappingElement)settings).Bookmark;
        }

        public void Add(PageMappingElement mapping)
        {
            if (mapping == null)
            {
                throw new ArgumentNullException("mapping");
            }

            base.BaseAdd(mapping);
        }
    }

    public class PageMappingElement : ConfigurationElement
    {
        private const string _bookmark = "bookmark";
        private const string _location = "location";
        private const string _directaccessible = "directaccessible";

        public PageMappingElement()
        {
        }

        [ConfigurationProperty(_bookmark, DefaultValue = null)]
        public string Bookmark
        {
            get
            {
                return (string)base[_bookmark];
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }

                base[_bookmark] = value;
            }
        }

        [ConfigurationProperty(_location, DefaultValue = null)]
        public string Location
        {
            get
            {
                return (string)base[_location];
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }

                base[_location] = value;
            }
        }

        /// <summary>
        /// Added code
        /// Is the page directly accessible.
        /// If you access this page directly the workflow will start from that certain location
        /// </summary>
        [ConfigurationProperty(_directaccessible, DefaultValue = false)]
        public bool Directaccessible
        {
            get
            {
                return (bool)base[_directaccessible];
            }
            set
            {
                base[_directaccessible] = value;
            }
        }
    }
}